Entry

Struct Entry 

pub struct Entry<'t> {
    table: &'t Table,
    id: Handle,
}
An immutable, object-like entry in a Table.

Entry wraps a Table and a Handle, and provides an ergonomic interface for querying information about the state of the node at that Handle.

Its mutable counterpart, EntryMut, provides a similar interface for modifying the state of the Table.

Fields

table: &'t Tableid: Handle

Implementations

Source

impl<'t> Entry<'t>

pub const fn new(table: &'t Table, id: Handle) -> Self

Constructs a new Entry from shared &Table and a Handle.

pub const fn id(&self) -> Handle

Gets the Handle associated with this Entry

pub const fn inner(&'t self) -> &'t Table

Gets the Table associated with this Entry

pub fn kind(&self) -> Option<&NodeKind>

Gets the NodeKind of this Entry in the Table

pub const fn root(&self) -> Entry<'_>

Gets the Entry of the root node in the Table

pub fn children(&self) -> Option<&SymMap<Handle>>

Gets the children of this node

pub fn lazy_imports(&self) -> Option<&SymMap<Path>>

Gets the lazy-imports list for this node

pub fn glob_imports(&self) -> Option<&[Path]>

Gets the glob-imports list for this node

pub fn meta(&self) -> Option<&[Expr]>

Gets the meta-Expr list for this node

pub fn name(&self) -> Option<Sym>

Gets an identifying Symbol for this node, if possible

pub const fn with_id(&self, id: Handle) -> Entry<'t>

Constructs another Entry with the given Handle

pub fn nav(&self, path: &[Sym]) -> Option<Entry<'t>>

Navigates to another Entry

pub fn parent(&self) -> Option<Entry<'t>>

Gets the parent of this Entry

pub fn ty(&self) -> Option<&'t TypeKind>

Gets the TypeKind of this Entry

pub fn impl_target(&self) -> Option<Entry<'_>>

Gets the impl target of this Entry

pub fn selfty(&self) -> Option<Entry<'_>>

Gets the Self type of this Entry